@@ -18,6 +18,8 @@ function _aws_cdk_aws_iot_actions_LambdaFunctionAction(p) {
 }
 function _aws_cdk_aws_iot_actions_CloudWatchLogsAction(p) {
 }
+function _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateAction(p) {
+}
 function _aws_cdk_aws_iot_actions_FirehosePutRecordActionProps(p) {
     if (p == null)
         return;
@@ -26,11 +28,9 @@ function _aws_cdk_aws_iot_actions_FirehosePutRecordActionProps(p) {
         _aws_cdk_aws_iot_actions_FirehoseRecordSeparator(p.recordSeparator);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_iot_actions_KinesisPutRecordAction(p) {
-}
 function _aws_cdk_aws_iot_actions_FirehosePutRecordAction(p) {
 }
-function _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateAction(p) {
+function _aws_cdk_aws_iot_actions_KinesisPutRecordAction(p) {
 }
 function _aws_cdk_aws_iot_actions_S3PutObjectAction(p) {
 }
@@ -53,5 +53,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_iot_actions_FirehoseRecordSeparator, _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps, _aws_cdk_aws_iot_actions_KinesisPutRecordActionProps, _aws_cdk_aws_iot_actions_SqsQueueActionProps, _aws_cdk_aws_iot_actions_CommonActionProps, _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricAction, _aws_cdk_aws_iot_actions_LambdaFunctionAction, _aws_cdk_aws_iot_actions_CloudWatchLogsAction, _aws_cdk_aws_iot_actions_FirehosePutRecordActionProps, _aws_cdk_aws_iot_actions_KinesisPutRecordAction, _aws_cdk_aws_iot_actions_FirehosePutRecordAction, _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateAction, _aws_cdk_aws_iot_actions_S3PutObjectAction, _aws_cdk_aws_iot_actions_SqsQueueAction, _aws_cdk_aws_iot_actions_S3PutObjectActionProps };
+module.exports = { print, _aws_cdk_aws_iot_actions_FirehoseRecordSeparator, _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps, _aws_cdk_aws_iot_actions_KinesisPutRecordActionProps, _aws_cdk_aws_iot_actions_SqsQueueActionProps, _aws_cdk_aws_iot_actions_CommonActionProps, _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricAction, _aws_cdk_aws_iot_actions_LambdaFunctionAction, _aws_cdk_aws_iot_actions_CloudWatchLogsAction, _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateAction, _aws_cdk_aws_iot_actions_FirehosePutRecordActionProps, _aws_cdk_aws_iot_actions_FirehosePutRecordAction, _aws_cdk_aws_iot_actions_KinesisPutRecordAction, _aws_cdk_aws_iot_actions_S3PutObjectAction, _aws_cdk_aws_iot_actions_SqsQueueAction, _aws_cdk_aws_iot_actions_S3PutObjectActionProps };
 module.exports.DeprecationError = DeprecationError;
